@@ -2,11 +2,11 @@ from .basic_commands import try_traceback
 from .basic_commands import func_timer
 
 from .basic_commands import fprint
-from .basic_commands import enter_to_continue
 from .basic_commands import finput
+from .basic_commands import enter_to_continue
 from .basic_commands import choose_from_list
+from .basic_commands import read_file
 from .basic_commands import create_file_dir
 from .basic_commands import remove_file_dir
-from .basic_commands import read_file
-from .basic_commands import get_path_for_file
-from .basic_commands import join_dir
\ No newline at end of file
+from .basic_commands import get_dir_path_for_file
+from .basic_commands import join_path
\ No newline at end of file
